diff include/RTAudio.h @ 19:c98863e63174 matrix_gpio

Renamed matrixGpio to digital and matrix to analog
author Giulio Moro <giuliomoro@yahoo.it>
date Thu, 30 Apr 2015 16:58:41 +0100
parents 670be80463a3
children ad5cd8dd99b3
line wrap: on
line diff
--- a/include/RTAudio.h	Thu Apr 30 16:02:47 2015 +0100
+++ b/include/RTAudio.h	Thu Apr 30 16:58:41 2015 +0100
@@ -39,15 +39,15 @@
 // real-time audio system
 typedef struct {
 	// These items might be adjusted by the user:
-	int periodSize;			// Number of (matrix) frames per period; audio is twice this
+	int periodSize;			// Number of (analog) frames per period; audio is twice this
 	int beginMuted;			// Whether to begin with the speakers muted
 	float dacLevel;			// Level for the audio DAC output
 	float adcLevel;			// Level for the audio ADC input
 	float headphoneLevel;	// Level for the headphone output
-	int useMatrix;			// Whether to use the matrix
-	int useMatrixGpio;		// Whether to use the 16 programmable GPIOs
-	int numMatrixChannels;	// How many channels for the ADC and DAC
-	int numMatrixGpioChannels;	// How many channels for the GPIOs
+	int useAnalog;			// Whether to use the analog
+	int useDigital;		// Whether to use the 16 programmable GPIOs
+	int numAnalogChannels;	// How many channels for the ADC and DAC
+	int numDigitalChannels;	// How many channels for the GPIOs
 	int verbose;			// Whether to use verbose logging
 	char pruFilename[MAX_PRU_FILENAME_LENGTH]; //the external .bin file to load. If empty will use PRU code from pru_rtaudio_bin.h
 	// These items are hardware-dependent and should only be changed